//
// GlGrph.hpp:
//	Interface definition of classes graphicsActor, XYZ, hand, Rectangle,
//      and a couple of old C functions.
//
// Purpose:
//	Define the relevant parts of a graphics object that represents
//	the glove in 3-D space.
//
// Author(s): Mark Pflaging   C-serve  70233,1552
// Copyright 1992   Mark Thomas Pflaging
//
// Also see authorships in OOPGLOVE.DOC.
// Date:    5/15/92 - 9/21/92
//
#ifndef __GLGRPH_HPP
#define __GLGRPH_HPP

#include <graphics.h>

#ifndef __HARDWARE_HPP
#include "hardware.hpp"
#endif

#ifndef __INI_HPP
#include "ini.hpp"
#endif

class hand;

// Rectangle is a "convenience" class for now.
class Rectangle {
	static double thetaRad;
public:
	int left, top, right, bottom;
	void setThetaRad(double value);
	void setRectValues(int larg, int targ, int rarg, int barg) {
		left = larg;
		top = targ;
		right = rarg;
		bottom = barg;
	}
	void scalePoint(double x, double y, int & new_x, int & new_y);
};

class XYZ : Rectangle {
	int x, y, z;
	void setValues(int xarg, int yarg, int zarg) {
		x = xarg; y = yarg; z = zarg;
	}
public:
	void scaleToGlove( GloveData & gd);
	void rectangle();
	void displayGlove(gloveDriver &gd, hand & myHand);
	void erase(int leaveTrail);
	operator==(XYZ & other) {
		return ((x == other.x) && (y == other.y) && (z == other.z));
	}
};

// This struct is needed for glove drawing data.
typedef struct {
	int numGroups, pointsPerGroup;
	int *data;
} HandType, * HandTypePtr;

class hand {
	int * data[5];
	HandTypePtr original;
	int fillMode;
protected:
	static char * title;
public:
	hand(InitFile & ini);
	void drawOne(Fingers::handParts index, int numParts);
	void drawAll(gloveDriver & gd);
	void scaleRect(Rectangle &scaler);
};

class graphicsActor : public hand {
	int xx;		// plot position.
	int drawn;	// set if cursor to be erased.
	void displayGlove(GloveData& gd);
	XYZ oldData;	// MAYBE a little bigger than it needs to be.
	int oldFingers;
	int leaveTrails;
	int gloveActive, handActive, infoActive;

public:
	graphicsActor(InitFile & ini);
	~graphicsActor() { closegraph(); }

	static void displayHelp();
	void drawGlove(gloveDriver &gd);
	void eraseGlove();
	static void infoDisplay(gloveDriver & gd);
	static void infoErase(int start);
	void test(gloveDriver& gd);

	// The next one's from a previous version.
	friend void drawGlovePlot(graphicsActor & obj, gloveDriver& gd);
};

// C functions from a previous version.
void drawFingers(gloveDriver& gd);
void infoDisplay();
void eraseFingers();

#endif
